==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/event.FrontEndUsers.OnDeleteUser.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

// delete checkins?
if( $this->GetPreference('feu_ondelete_cleancheckins',1) ) {
  $query = new cgsa_checkin_query(array('owner'->$params['id']));
  $rs = $query->execute();
  if( $rs ) {
    while( !$rs->EOF ) {
      $ob = $rs->fields;
      $ob->delete();
    }
  }
}

// @todo: delete favorites

// delete this user from all people who have this guy as a friend
$friends = cgsa_friends::get_friends($params['id']);
if( is_array($friends) && count($friends) ) {
  foreach( $friends as $one ) {
    cgsa_friends::remove_friendship($one,$params['id']);
  }
}
// delete this users friend data
cgsa_friends::delete_all($params['id']);

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/event.FrontEndUsers.OnDeleteUser.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;

// delete checkins?
if( $this->GetPreference('feu_ondelete_cleancheckins',1) ) {
  $query = new cgsa_checkin_query(array('owner'=>$params['id']));
  $rs = $query->execute();
  if( $rs ) {
    while( !$rs->EOF ) {
      $ob = $rs->fields;
      $ob->delete();
    }
  }
}

// @todo: delete favorites
cgsa_favorites::delete_all($params['id']);

// delete this user from all people who have this guy as a friend
$friends = cgsa_friends::get_friends($params['id']);
if( is_array($friends) && count($friends) ) {
  foreach( $friends as $one ) {
    cgsa_friends::remove_friendship($one,$params['id']);
  }
}

// delete this users friend data
cgsa_friends::delete_all($params['id']);

#
# EOF
#
?>
